==> gi-assets-algorithm-2.3.16.tgz: package/es/NodeImportance/propertyContent.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectDestructuringEmpty(obj) { if (obj == null) throw new TypeError("Cannot destructure " + obj); }
/**
 * author:shiwu.wyy@antgroup.com
 */
import { useContext } from '@antv/gi-sdk';
import { Form, Select, Spin } from 'antd';
import React, { useState } from 'react';
import { locale, MappingWay } from './registerMeta';
import $i18n from '../i18n';
var Option = Select.Option;
var PropertyContent = function PropertyContent(_ref) {
  var type = _ref.type,
    visible = _ref.visible,
    form = _ref.form,
    properties = _ref.properties;
  var _a;
  _objectDestructuringEmpty(useContext());
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    loading = _useState2[0],
    setLoading = _useState2[1];
  return /*#__PURE__*/React.createElement("div", {
    className: "algo-body algo-body-property"
  }, /*#__PURE__*/React.createElement("span", {
    style: {
      marginLeft: 8
    }
  }, /*#__PURE__*/React.createElement(Form.Item, {
    rules: [{
      required: visible,
      message: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CannotBeEmpty',
        dm: '不可为空'
      })
    }],
    name: "".concat(type, "-property.property"),
    key: "".concat(type, "-property.property"),
    label: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.Properties',
      dm: '属性'
    })
  }, /*#__PURE__*/React.createElement(Select, {
    placeholder: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.PleaseSelect',
      dm: '请选择'
    }),
    dropdownMatchSelectWidth: false,
    notFoundContent: loading ? /*#__PURE__*/React.createElement(Spin, null) : $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.NoData',
      dm: '无数据'
    })
  }, (_a = properties === null || properties === void 0 ? void 0 : properties.map) === null || _a === void 0 ? void 0 : _a.call(properties, function (property) {
    return /*#__PURE__*/React.createElement(Option, {
      value: property,
      key: property
    }, property);
  })))), type === 'edge' && /*#__PURE__*/React.createElement("span", {
    style: {
      marginLeft: 8
    }
  }, /*#__PURE__*/React.createElement(Form.Item, {
    rules: [{
      required: visible,
      message: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CannotBeEmpty',
        dm: '不可为空'
      })
    }],
    name: "".concat(type, "-property.calcway"),
    key: "".concat(type, "-property.calcway"),
    label: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CalculationMethod',
      dm: '计算方式'
    })
  }, /*#__PURE__*/React.createElement(Select, {
    placeholder: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.PleaseSelect',
      dm: '请选择'
    }),
    dropdownMatchSelectWidth: false,
    dropdownClassName: "calc",
    //@ts-ignore
    getPopupContainer: function getPopupContainer() {
      return document.getElementById('select-drop-down-area');
    }
  }, /*#__PURE__*/React.createElement(Option, {
    value: 'sort',
    key: 'sort'
  }, locale['sort'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "calc-tip"
  }, locale['sort-tip'])), /*#__PURE__*/React.createElement(Option, {
    value: 'count',
    key: 'count'
  }, locale['count'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "calc-tip"
  }, locale['count-tip']))))), /*#__PURE__*/React.createElement("span", {
    style: {
      marginLeft: 8
    }
  }, /*#__PURE__*/React.createElement(Form.Item, {
    rules: [{
      required: visible,
      message: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CannotBeEmpty',
        dm: '不可为空'
      })
    }],
    name: "".concat(type, "-property.mappingway"),
    key: "".concat(type, "-property.mappingway"),
    initialValue: MappingWay.Positive,
    label: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.MappingMethod',
      dm: '映射方式'
    })
  }, /*#__PURE__*/React.createElement(Select, {
    placeholder: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.PleaseSelect',
      dm: '请选择'
    }),
    dropdownMatchSelectWidth: false,
    dropdownClassName: "mapping",
    //@ts-ignore
    getPopupContainer: function getPopupContainer() {
      return document.getElementById('select-drop-down-area');
    }
  }, /*#__PURE__*/React.createElement(Option, {
    value: MappingWay.Positive,
    key: MappingWay.Positive
  }, locale['positive-correlation'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "mapping-tip"
  }, locale['positive-tip'])), /*#__PURE__*/React.createElement(Option, {
    value: MappingWay.Negative,
    key: MappingWay.Negative
  }, locale['negative-correlation'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "mapping-tip"
  }, locale['negative-tip']))))));
};
export default PropertyContent;

==> gi-assets-algorithm-2.3.19.tgz: package/es/NodeImportance/propertyContent.js <==
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
function _objectDestructuringEmpty(t) { if (null == t) throw new TypeError("Cannot destructure " + t); }
/**
 * author:shiwu.wyy@antgroup.com
 */
import { useContext } from '@antv/gi-sdk';
import { Form, Select, Spin } from 'antd';
import React, { useState } from 'react';
import { locale, MappingWay } from './registerMeta';
import $i18n from '../i18n';
var Option = Select.Option;
var PropertyContent = function PropertyContent(_ref) {
  var type = _ref.type,
    visible = _ref.visible,
    form = _ref.form,
    properties = _ref.properties;
  var _a;
  _objectDestructuringEmpty(useContext());
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    loading = _useState2[0],
    setLoading = _useState2[1];
  return /*#__PURE__*/React.createElement("div", {
    className: "algo-body algo-body-property"
  }, /*#__PURE__*/React.createElement("span", {
    style: {
      marginLeft: 8
    }
  }, /*#__PURE__*/React.createElement(Form.Item, {
    rules: [{
      required: visible,
      message: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CannotBeEmpty',
        dm: '不可为空'
      })
    }],
    name: "".concat(type, "-property.property"),
    key: "".concat(type, "-property.property"),
    label: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.Properties',
      dm: '属性'
    })
  }, /*#__PURE__*/React.createElement(Select, {
    placeholder: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.PleaseSelect',
      dm: '请选择'
    }),
    dropdownMatchSelectWidth: false,
    notFoundContent: loading ? ( /*#__PURE__*/React.createElement(Spin, null)) : $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.NoData',
      dm: '无数据'
    })
  }, (_a = properties === null || properties === void 0 ? void 0 : properties.map) === null || _a === void 0 ? void 0 : _a.call(properties, function (property) {
    return /*#__PURE__*/React.createElement(Option, {
      value: property,
      key: property
    }, property);
  })))), type === 'edge' && ( /*#__PURE__*/React.createElement("span", {
    style: {
      marginLeft: 8
    }
  }, /*#__PURE__*/React.createElement(Form.Item, {
    rules: [{
      required: visible,
      message: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CannotBeEmpty',
        dm: '不可为空'
      })
    }],
    name: "".concat(type, "-property.calcway"),
    key: "".concat(type, "-property.calcway"),
    label: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CalculationMethod',
      dm: '计算方式'
    })
  }, /*#__PURE__*/React.createElement(Select, {
    placeholder: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.PleaseSelect',
      dm: '请选择'
    }),
    dropdownMatchSelectWidth: false,
    dropdownClassName: "calc",
    //@ts-ignore
    getPopupContainer: function getPopupContainer() {
      return document.getElementById('select-drop-down-area');
    }
  }, /*#__PURE__*/React.createElement(Option, {
    value: 'sort',
    key: 'sort'
  }, locale['sort'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "calc-tip"
  }, locale['sort-tip'])), /*#__PURE__*/React.createElement(Option, {
    value: 'count',
    key: 'count'
  }, locale['count'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "calc-tip"
  }, locale['count-tip'])))))), /*#__PURE__*/React.createElement("span", {
    style: {
      marginLeft: 8
    }
  }, /*#__PURE__*/React.createElement(Form.Item, {
    rules: [{
      required: visible,
      message: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.CannotBeEmpty',
        dm: '不可为空'
      })
    }],
    name: "".concat(type, "-property.mappingway"),
    key: "".concat(type, "-property.mappingway"),
    initialValue: MappingWay.Positive,
    label: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.MappingMethod',
      dm: '映射方式'
    })
  }, /*#__PURE__*/React.createElement(Select, {
    placeholder: $i18n.get({
      id: 'gi-assets-algorithm.src.NodeImportance.propertyContent.PleaseSelect',
      dm: '请选择'
    }),
    dropdownMatchSelectWidth: false,
    dropdownClassName: "mapping",
    //@ts-ignore
    getPopupContainer: function getPopupContainer() {
      return document.getElementById('select-drop-down-area');
    }
  }, /*#__PURE__*/React.createElement(Option, {
    value: MappingWay.Positive,
    key: MappingWay.Positive
  }, locale['positive-correlation'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "mapping-tip"
  }, locale['positive-tip'])), /*#__PURE__*/React.createElement(Option, {
    value: MappingWay.Negative,
    key: MappingWay.Negative
  }, locale['negative-correlation'], /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("p", {
    className: "mapping-tip"
  }, locale['negative-tip']))))));
};
export default PropertyContent;
